@@ -1,7 +1,11 @@
 
 __title__ = 'pyvboxmanage'
 __author__ = 'Nicholas de Jong <me@nicholasdejong.com>'
-__version__ = '0.3.1'
+__version__ = '0.4.0'
 
 __exec_timeout_default__ = 120
 __config_import_recursion_limit__ = 20
+
+__variable_tag_open__ = '{'
+__variable_tag_close__ = '}'
+
